##install dependencies

npm init playwright@latest -- --quiet
npm install lighthouse playwright-lighthouse

## run the script
npx playwright test --headed  # Run in browser (debug)
npx playwright test --workers=3  # Parallel execution

# Generate reports
npx playwright show-report  # Built-in HTML report
# For Allure:
npm install @playwright/test allure-playwright
npx playwright test --reporter=line,allure-playwright
###########################################################

import { test, expect, chromium } from '@playwright/test';
import { lighthouse } from 'lighthouse';
import { writeFileSync } from 'fs';

// Constants
const WEBSITE_URL = 'https://www.kaiyvenleslie.com';

// Configure global setup (optional)
test.beforeAll(async () => {
  // Ensure site is reachable
  const response = await fetch(WEBSITE_URL);
  expect(response.status).toBe(200);
});

// --- FUNCTIONAL TESTS ---
test('Homepage loads with correct title', async ({ page }) => {
  await page.goto(WEBSITE_URL);
  await expect(page).toHaveTitle(/Kaiyven Leslie/);
});

test('Navigation links are not broken', async ({ page }) => {
  await page.goto(WEBSITE_URL);
  const links = page.locator('nav a');
  const count = await links.count();

  for (let i = 0; i < count; i++) {
    const link = links.nth(i);
    const href = await link.getAttribute('href');
    if (href && !href.startsWith('mailto:')) {
      await link.click();
      await expect(page).toHaveURL(href);
      await page.goBack();
    }
  }
});

test('Contact form submits successfully', async ({ page }) => {
  await page.goto(`${WEBSITE_URL}/contact`);
  await page.fill('input[name="name"]', 'Test User');
  await page.fill('input[name="email"]', 'test@example.com');
  await page.click('button[type="submit"]');
  
  // Verify success message (adjust selector)
  await expect(page.locator('.success-message')).toContainText('Thank you');
});

// --- NON-FUNCTIONAL TESTS ---
test('Page response time < 2s', async ({ page }) => {
  const start = Date.now();
  await page.goto(WEBSITE_URL);
  const loadTime = Date.now() - start;
  expect(loadTime).toBeLessThan(2000); // 2 seconds
});

test('HTTPS and security headers', async ({ request }) => {
  const response = await request.get(WEBSITE_URL);
  expect(response.url()).toMatch(/^https:\/\//);
  expect(response.headers()['x-content-type-options']).toBe('nosniff');
});

test('Mobile responsiveness', async ({ playwright }) => {
  const iPhone = playwright.devices['iPhone 13'];
  const browser = await chromium.launch();
  const context = await browser.newContext({ ...iPhone });
  const page = await context.newPage();
  
  await page.goto(WEBSITE_URL);
  await expect(page.locator('meta[name="viewport"]')).toBeAttached();
  await browser.close();
});

// --- PERFORMANCE AUDIT (Lighthouse) ---
test('Lighthouse performance score >= 80', async () => {
  const browser = await chromium.launch();
  const port = new URL(browser.wsEndpoint()).port;
  const result = await lighthouse(WEBSITE_URL, { port });
  
  expect(result.lhr.categories.performance.score).toBeGreaterThanOrEqual(0.8);
  writeFileSync('lighthouse-report.json', JSON.stringify(result.lhr, null, 2));
  await browser.close();
});